@@ -1,12 +1,10 @@
 package SVN::Notify::HTML::ColorDiff;
 
-# $Id: ColorDiff.pm 4143 2008-07-18 21:23:02Z david $
-
 use strict;
 use HTML::Entities;
 use SVN::Notify::HTML ();
 
-$SVN::Notify::HTML::ColorDiff::VERSION = '2.78';
+$SVN::Notify::HTML::ColorDiff::VERSION = '2.87';
 @SVN::Notify::HTML::ColorDiff::ISA = qw(SVN::Notify::HTML);
 
 =head1 Name
@@ -248,7 +246,7 @@ __END__
 
 =item L<SVN::Notify::HTML|SVN::Notify::HTML>
 
-=item CVSspam: L<http://www.badgers-in-foil.co.uk/projects/cvsspam/>
+=item L<CVSspam|http://www.badgers-in-foil.co.uk/projects/cvsspam/>
 
 =back
 
@@ -273,11 +271,11 @@ body. Maybe use absolute positioning CSS?
 
 =head1 Author
 
-David E. Wheeler <david@kineticode.com>
+David E. Wheeler <david@justatheory.com>
 
 =head1 Copyright and License
 
-Copyright (c) 2004-2008 Kineticode, Inc. Some Rights Reserved.
+Copyright (c) 2004-2018 David E. Wheeler. Some Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
